# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/agent.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/agent.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1a\x66lyteidl/admin/agent.proto\x12\x0e\x66lyteidl.admin\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1d\x66lyteidl/core/interface.proto\"\x84\x01\n\x11\x43reateTaskRequest\x12)\n\x06inputs\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\x12-\n\x08template\x18\x02 \x01(\x0b\x32\x1b.flyteidl.core.TaskTemplate\x12\x15\n\routput_prefix\x18\x03 \x01(\t\"+\n\x12\x43reateTaskResponse\x12\x15\n\rresource_meta\x18\x01 \x01(\x0c\":\n\x0eGetTaskRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x15\n\rresource_meta\x18\x02 \x01(\x0c\"=\n\x0fGetTaskResponse\x12*\n\x08resource\x18\x01 \x01(\x0b\x32\x18.flyteidl.admin.Resource\"\\\n\x08Resource\x12$\n\x05state\x18\x01 \x01(\x0e\x32\x15.flyteidl.admin.State\x12*\n\x07outputs\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"=\n\x11\x44\x65leteTaskRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x15\n\rresource_meta\x18\x02 \x01(\x0c\"\x14\n\x12\x44\x65leteTaskResponse*^\n\x05State\x12\x15\n\x11RETRYABLE_FAILURE\x10\x00\x12\x15\n\x11PERMANENT_FAILURE\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tSUCCEEDED\x10\x04\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_core_dot_interface__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='flyteidl.admin.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RETRYABLE_FAILURE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=616,
  serialized_end=710,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
RETRYABLE_FAILURE = 0
PERMANENT_FAILURE = 1
PENDING = 2
RUNNING = 3
SUCCEEDED = 4



_CREATETASKREQUEST = _descriptor.Descriptor(
  name='CreateTaskRequest',
  full_name='flyteidl.admin.CreateTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.CreateTaskRequest.inputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='flyteidl.admin.CreateTaskRequest.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_prefix', full_name='flyteidl.admin.CreateTaskRequest.output_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=267,
)


_CREATETASKRESPONSE = _descriptor.Descriptor(
  name='CreateTaskResponse',
  full_name='flyteidl.admin.CreateTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_meta', full_name='flyteidl.admin.CreateTaskResponse.resource_meta', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=312,
)


_GETTASKREQUEST = _descriptor.Descriptor(
  name='GetTaskRequest',
  full_name='flyteidl.admin.GetTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.admin.GetTaskRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_meta', full_name='flyteidl.admin.GetTaskRequest.resource_meta', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=372,
)


_GETTASKRESPONSE = _descriptor.Descriptor(
  name='GetTaskResponse',
  full_name='flyteidl.admin.GetTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='flyteidl.admin.GetTaskResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=435,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='flyteidl.admin.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.Resource.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.admin.Resource.outputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=529,
)


_DELETETASKREQUEST = _descriptor.Descriptor(
  name='DeleteTaskRequest',
  full_name='flyteidl.admin.DeleteTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.admin.DeleteTaskRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_meta', full_name='flyteidl.admin.DeleteTaskRequest.resource_meta', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=592,
)


_DELETETASKRESPONSE = _descriptor.Descriptor(
  name='DeleteTaskResponse',
  full_name='flyteidl.admin.DeleteTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=614,
)

_CREATETASKREQUEST.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_CREATETASKREQUEST.fields_by_name['template'].message_type = flyteidl_dot_core_dot_tasks__pb2._TASKTEMPLATE
_GETTASKRESPONSE.fields_by_name['resource'].message_type = _RESOURCE
_RESOURCE.fields_by_name['state'].enum_type = _STATE
_RESOURCE.fields_by_name['outputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
DESCRIPTOR.message_types_by_name['CreateTaskRequest'] = _CREATETASKREQUEST
DESCRIPTOR.message_types_by_name['CreateTaskResponse'] = _CREATETASKRESPONSE
DESCRIPTOR.message_types_by_name['GetTaskRequest'] = _GETTASKREQUEST
DESCRIPTOR.message_types_by_name['GetTaskResponse'] = _GETTASKRESPONSE
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['DeleteTaskRequest'] = _DELETETASKREQUEST
DESCRIPTOR.message_types_by_name['DeleteTaskResponse'] = _DELETETASKRESPONSE
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTaskRequest = _reflection.GeneratedProtocolMessageType('CreateTaskRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATETASKREQUEST,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.CreateTaskRequest)
  ))
_sym_db.RegisterMessage(CreateTaskRequest)

CreateTaskResponse = _reflection.GeneratedProtocolMessageType('CreateTaskResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATETASKRESPONSE,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.CreateTaskResponse)
  ))
_sym_db.RegisterMessage(CreateTaskResponse)

GetTaskRequest = _reflection.GeneratedProtocolMessageType('GetTaskRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTASKREQUEST,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.GetTaskRequest)
  ))
_sym_db.RegisterMessage(GetTaskRequest)

GetTaskResponse = _reflection.GeneratedProtocolMessageType('GetTaskResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTASKRESPONSE,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.GetTaskResponse)
  ))
_sym_db.RegisterMessage(GetTaskResponse)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCE,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Resource)
  ))
_sym_db.RegisterMessage(Resource)

DeleteTaskRequest = _reflection.GeneratedProtocolMessageType('DeleteTaskRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETETASKREQUEST,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.DeleteTaskRequest)
  ))
_sym_db.RegisterMessage(DeleteTaskRequest)

DeleteTaskResponse = _reflection.GeneratedProtocolMessageType('DeleteTaskResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETETASKRESPONSE,
  __module__ = 'flyteidl.admin.agent_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.DeleteTaskResponse)
  ))
_sym_db.RegisterMessage(DeleteTaskResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/agent.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import agent_pb2 as flyteidl_dot_admin_dot_agent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/agent.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n\x1c\x66lyteidl/service/agent.proto\x12\x10\x66lyteidl.service\x1a\x1a\x66lyteidl/admin/agent.proto2\x8f\x02\n\x11\x41syncAgentService\x12U\n\nCreateTask\x12!.flyteidl.admin.CreateTaskRequest\x1a\".flyteidl.admin.CreateTaskResponse\"\x00\x12L\n\x07GetTask\x12\x1e.flyteidl.admin.GetTaskRequest\x1a\x1f.flyteidl.admin.GetTaskResponse\"\x00\x12U\n\nDeleteTask\x12!.flyteidl.admin.DeleteTaskRequest\x1a\".flyteidl.admin.DeleteTaskResponse\"\x00\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_agent__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ASYNCAGENTSERVICE = _descriptor.ServiceDescriptor(
  name='AsyncAgentService',
  full_name='flyteidl.service.AsyncAgentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=79,
  serialized_end=350,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTask',
    full_name='flyteidl.service.AsyncAgentService.CreateTask',
    index=0,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_agent__pb2._CREATETASKREQUEST,
    output_type=flyteidl_dot_admin_dot_agent__pb2._CREATETASKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='flyteidl.service.AsyncAgentService.GetTask',
    index=1,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_agent__pb2._GETTASKREQUEST,
    output_type=flyteidl_dot_admin_dot_agent__pb2._GETTASKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTask',
    full_name='flyteidl.service.AsyncAgentService.DeleteTask',
    index=2,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_agent__pb2._DELETETASKREQUEST,
    output_type=flyteidl_dot_admin_dot_agent__pb2._DELETETASKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYNCAGENTSERVICE)

DESCRIPTOR.services_by_name['AsyncAgentService'] = _ASYNCAGENTSERVICE

# @@protoc_insertion_point(module_scope)
